server

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HephaestusServer

type HephaestusServer struct {
	pb.UnimplementedHephaestusServiceServer
	// contains filtered or unexported fields
}

HephaestusServer implements the HephaestusService gRPC interface

func NewHephaestusServer

func NewHephaestusServer(
	nodeManager hephaestus.NodeLifecycleManager,
	logProcessor hephaestus.LogProcessingService,
	modelService hephaestus.ModelServiceProvider,
	remoteRepoService hephaestus.RemoteRepositoryService,
	metricsCollector hephaestus.MetricsCollectionService,
) *HephaestusServer

NewHephaestusServer creates a new instance of the Hephaestus server

func (*HephaestusServer) DeleteNode

DeleteNode removes a node from the system

func (*HephaestusServer) GetNodeStatus

GetNodeStatus retrieves the current status of a node

func (*HephaestusServer) InitializeNode

InitializeNode initializes a new node with the provided configuration

func (*HephaestusServer) UpdateNodeConfiguration

UpdateNodeConfiguration updates the configuration of an existing node

Jump to