Documentation
¶
Index ¶
- type ModelServiceClient
- type ModelSession
- type Service
- func (s *Service) Cleanup(ctx context.Context, nodeID string) error
- func (s *Service) GenerateSolutionProposal(ctx context.Context, entry *hephaestus.LogEntryData, ...) (*hephaestus.ProposedSolution, error)
- func (s *Service) Initialize(ctx context.Context, config *hephaestus.ModelServiceConfiguration) error
- func (s *Service) ValidateSolutionProposal(ctx context.Context, solution *hephaestus.ProposedSolution) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ModelServiceClient ¶
type ModelServiceClient interface {
GenerateSolution(ctx context.Context, entry *hephaestus.LogEntryData, config *hephaestus.ModelServiceConfiguration) (*hephaestus.ProposedSolution, error)
}
ModelServiceClient defines the interface for model service interactions
type ModelSession ¶
type ModelSession struct {
NodeID string
LastActive time.Time
IsActive bool
Configuration *hephaestus.ModelServiceConfiguration
}
ModelSession represents an active model interaction session
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service implements the ModelServiceProvider interface
func NewService ¶
func NewService(client ModelServiceClient, metricsCollector hephaestus.MetricsCollectionService) *Service
NewService creates a new instance of the model service
func (*Service) GenerateSolutionProposal ¶
func (s *Service) GenerateSolutionProposal(ctx context.Context, entry *hephaestus.LogEntryData, repo hephaestus.RepositoryManager) (*hephaestus.ProposedSolution, error)
GenerateSolutionProposal attempts to generate a solution for the given log entry
func (*Service) Initialize ¶
func (s *Service) Initialize(ctx context.Context, config *hephaestus.ModelServiceConfiguration) error
Initialize sets up the model service with the provided configuration
func (*Service) ValidateSolutionProposal ¶
func (s *Service) ValidateSolutionProposal(ctx context.Context, solution *hephaestus.ProposedSolution) error
ValidateSolutionProposal validates a generated solution
Click to show internal directories.
Click to hide internal directories.