Documentation
¶
Index ¶
- type Manager
- func (m *Manager) CreateSystemNode(ctx context.Context, config *hephaestus.SystemConfiguration) (*hephaestus.SystemNode, error)
- func (m *Manager) DeleteSystemNode(ctx context.Context, nodeID string) error
- func (m *Manager) GetSystemNode(ctx context.Context, nodeID string) (*hephaestus.SystemNode, error)
- func (m *Manager) UpdateNodeOperationalStatus(ctx context.Context, nodeID string, status hephaestus.NodeStatus) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager implements the NodeLifecycleManager interface
func NewManager ¶
func NewManager( logProcessor hephaestus.LogProcessingService, modelService hephaestus.ModelServiceProvider, remoteRepoService hephaestus.RemoteRepositoryService, metricsCollector hephaestus.MetricsCollectionService, ) *Manager
NewManager creates a new instance of the node manager
func (*Manager) CreateSystemNode ¶
func (m *Manager) CreateSystemNode(ctx context.Context, config *hephaestus.SystemConfiguration) (*hephaestus.SystemNode, error)
CreateSystemNode creates a new node with the provided configuration
func (*Manager) DeleteSystemNode ¶
DeleteSystemNode removes a node from the system
func (*Manager) GetSystemNode ¶
func (m *Manager) GetSystemNode(ctx context.Context, nodeID string) (*hephaestus.SystemNode, error)
GetSystemNode retrieves a node by its identifier
func (*Manager) UpdateNodeOperationalStatus ¶
func (m *Manager) UpdateNodeOperationalStatus(ctx context.Context, nodeID string, status hephaestus.NodeStatus) error
UpdateNodeOperationalStatus updates the operational status of a node
Click to show internal directories.
Click to hide internal directories.