Documentation
¶
Index ¶
- type HephaestusServer
- func (s *HephaestusServer) DeleteNode(ctx context.Context, req *pb.DeleteNodeRequest) (*pb.DeleteNodeResponse, error)
- func (s *HephaestusServer) GetNodeStatus(ctx context.Context, req *pb.NodeStatusRequest) (*pb.NodeStatusResponse, error)
- func (s *HephaestusServer) InitializeNode(ctx context.Context, req *pb.InitializeNodeRequest) (*pb.InitializeNodeResponse, error)
- func (s *HephaestusServer) UpdateNodeConfiguration(ctx context.Context, req *pb.UpdateNodeConfigurationRequest) (*pb.UpdateNodeConfigurationResponse, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HephaestusServer ¶
type HephaestusServer struct {
pb.UnimplementedHephaestusServiceServer
// contains filtered or unexported fields
}
HephaestusServer implements the HephaestusService gRPC interface
func NewHephaestusServer ¶
func NewHephaestusServer( nodeManager hephaestus.NodeLifecycleManager, logProcessor hephaestus.LogProcessingService, modelService hephaestus.ModelServiceProvider, remoteRepoService hephaestus.RemoteRepositoryService, metricsCollector hephaestus.MetricsCollectionService, ) *HephaestusServer
NewHephaestusServer creates a new instance of the Hephaestus server
func (*HephaestusServer) DeleteNode ¶
func (s *HephaestusServer) DeleteNode(ctx context.Context, req *pb.DeleteNodeRequest) (*pb.DeleteNodeResponse, error)
DeleteNode removes a node from the system
func (*HephaestusServer) GetNodeStatus ¶
func (s *HephaestusServer) GetNodeStatus(ctx context.Context, req *pb.NodeStatusRequest) (*pb.NodeStatusResponse, error)
GetNodeStatus retrieves the current status of a node
func (*HephaestusServer) InitializeNode ¶
func (s *HephaestusServer) InitializeNode(ctx context.Context, req *pb.InitializeNodeRequest) (*pb.InitializeNodeResponse, error)
InitializeNode initializes a new node with the provided configuration
func (*HephaestusServer) UpdateNodeConfiguration ¶
func (s *HephaestusServer) UpdateNodeConfiguration(ctx context.Context, req *pb.UpdateNodeConfigurationRequest) (*pb.UpdateNodeConfigurationResponse, error)
UpdateNodeConfiguration updates the configuration of an existing node
Click to show internal directories.
Click to hide internal directories.